@@ -35,6 +35,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
+import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -912,7 +913,7 @@ public class Framework implements Closeable {
             );
             log.debug("BindRequest: {}", bindRequest);
 
-            log.debug("bind");
+            log.debug("User '{}' is performing bind request to: {}", user, connection.getConnectedAddress());
             BindResult bindResult = connection.bind(bindRequest);
             log.debug("BindResult: {}", bindResult);
 
@@ -1226,6 +1227,28 @@ public class Framework implements Closeable {
         log.debug("searchClose Return");
     }
 
+    class SearchExecute implements Callable<List<Map<String, List<String>>>> {
+
+        SearchInstance instance;
+        int pageSize;
+
+        public SearchExecute(SearchInstance instance, int pageSize) {
+            this.instance = instance;
+            this.pageSize = pageSize;
+        }
+
+        @Override
+        public List<Map<String, List<String>>> call() throws Exception {
+            List<Map<String, List<String>>> ret = new ArrayList<>();
+            List<Map<String, List<String>>> entries;
+            while ((entries = searchExecute(instance, 0)) != null) {
+                ret.addAll(entries);
+            }
+            return  ret;
+        }
+
+    }
+
     public List<Map<String, List<String>>> searchExecute(
         SearchInstance instance,
         int pageSize
@@ -1249,10 +1272,14 @@ public class Framework implements Closeable {
                     )
                 );
             }
-            log.debug("SearchRequest: {}", instance.searchRequest);
             instance.resumeCookie = null;
             SearchResult searchResult;
             try {
+                log.debug(
+                    "Performing SearchRequest '{}' request on server '{}'",
+                    instance.searchRequest,
+                    instance.connection.getConnectedAddress()
+                );
                 searchResult = instance.connection.search(instance.searchRequest);
             } catch (LDAPSearchException e) {
                 log.debug("SearchRequest: Exception {}", (Object)e);
